@@ -209,9 +209,9 @@ _startswith(s::Char, prefix::Union{String,Char}) = ncodeunits(s) >= ncodeunits(p
 _startswith(s::String, prefix::Union{Char,String,Regex}) = startswith(s, prefix)
 _startswith(s::String, prefix::UInt8) = startswith(s, Char(prefix))
 _startswith(s::Char, prefix::Regex) = startswith(string(s), prefix)
-_startswith(s::UInt8, prefix::Regex) = startswith(Char(s), prefix)
+_startswith(s::UInt8, prefix::Regex) = startswith(string(Char(s)), prefix)
 _startswith(s::UInt8, prefix::UInt8) = s == prefix
-_startswith(s::Char, prefix::UInt8) = first(codeunits(s)) == prefix
+_startswith(s::Char, prefix::UInt8) = codepoint(s) == UInt32(prefix)
 _startswith(a::Nothing, b) = false
 _startswith(a, b::Nothing) = false
 _startswith(a::Nothing, b::Nothing) = false
@@ -306,7 +306,7 @@ function token(x::MaybeToken, arg)
         asciival(x) || throw(ArgumentError("$arg argument must be ASCII"))
         return Token(x)
     elseif x isa Char
-        return Token(asciival(x) ? UInt8(x) : String(x))
+        return Token(asciival(x) ? UInt8(x) : string(x))
     elseif x isa Regex
         return Token(mkregex(x))
     else
@@ -439,10 +439,10 @@ end
 _xparse2(conf::AbstractConf{T}, source::Union{AbstractVector{UInt8}, IO}, pos, len, opts::Options=OPTIONS, ::Type{S}=returntype(T)) where {T, S} =
     Result(whitespace(false, false, false, true)(typeparser(opts)))(conf, source, pos, len, S)
 
-@inline xparse2(::Type{T}, source::SourceType, pos, len, options=OPTIONS, ::Type{S}=returntype(T)) where {T, S} =
+xparse2(::Type{T}, source::SourceType, pos, len, options=OPTIONS, ::Type{S}=returntype(T)) where {T, S} =
     result(T, xparse2(conf(T, options), source, pos, len, options, S))
 
-@inline function xparse2(conf::AbstractConf{T}, source::SourceType, pos, len, options=OPTIONS, ::Type{S}=returntype(T)) where {T, S}
+function xparse2(conf::AbstractConf{T}, source::SourceType, pos, len, options=OPTIONS, ::Type{S}=returntype(T)) where {T, S}
     buf = source isa AbstractString ? codeunits(source) : source
     if T === Number || supportedtype(T)
         return _xparse2(conf, buf, pos, len, options, S)
@@ -483,7 +483,7 @@ function checkdelim!(source::AbstractVector{UInt8}, pos, len, options::Options)
     return pos
 end
 
-@inline function _has_groupmark(opts::Options, code::ReturnCode)
+function _has_groupmark(opts::Options, code::ReturnCode)
     if opts.groupmark !== nothing
         isquoted = (code & QUOTED) != 0
         if isquoted || (opts.groupmark != opts.delim)
@@ -493,20 +493,46 @@ end
     return false
 end
 
+
+if isdefined(Base, :OncePerTask)
+    const _get_bigint = OncePerTask{BigInt}(() -> BigInt(; nbits=256))
+    # Note: This uses `() -> BigFloat()` instead of just `BigFloat` for --trim compatibility
+    const _get_bigfloats = OncePerTask{BigFloat}(() -> BigFloat())
+else
+    # N.B This code is not thread safe in the presence of thread migration
+    const BIGINT = BigInt[]
+    const BIGFLOATS = BigFloat[]
+
+    _get_bigfloats() = access_threaded(BigFloat, BIGFLOATS)
+    _get_bigint() = access_threaded(() -> (@static VERSION > v"1.5" ? BigInt(; nbits=256) : BigInt()), BIGINT)
+
+    function access_threaded(f, v::Vector)
+        tid = Threads.threadid()
+        0 < tid <= length(v) || _length_assert()
+        if @inbounds isassigned(v, tid)
+            @inbounds x = v[tid]
+        else
+            x = f()
+            @inbounds v[tid] = x
+        end
+        return x
+    end
+    @noinline _length_assert() =  @assert false "0 < tid <= v"
+
+    function __init__()
+        nt = isdefined(Base.Threads, :maxthreadid) ? Threads.maxthreadid() : Threads.nthreads()
+        resize!(empty!(BIGINT), nt)
+        resize!(empty!(BIGFLOATS), nt)
+        return
+    end
+end
+
 include("ints.jl")
 include("floats.jl")
 include("strings.jl")
 include("bools.jl")
 include("dates.jl")
 include("hexadecimal.jl")
-
-function __init__()
-    nt = isdefined(Base.Threads, :maxthreadid) ? Threads.maxthreadid() : Threads.nthreads()
-    resize!(empty!(BIGINT), nt)
-    resize!(empty!(BIGFLOATS), nt)
-    return
-end
-
 include("precompile.jl")
 
 end # module
